@@ -783,6 +783,7 @@ get_fs_component (const char *fs_cpe, int index)
   char *component = NULL;
   char *c;
   char *component_start, *component_end;
+  gboolean escaped;
 
   if (!fs_cpe)
     return NULL;
@@ -793,27 +794,38 @@ get_fs_component (const char *fs_cpe, int index)
   c = (char *) fs_cpe;
 
   /* find start of component */
+  escaped = FALSE;
   if (index == 0)
     component_start = c;
   else
     {
       for (int i = 0; *c != '\0' && i < index; c++)
         {
-          if (*c == ':' && c == fs_cpe)
-            i++;
-          else if (c > fs_cpe && *c == ':' && *(c - 1) != '\\')
+          if (*c == ':' && !escaped)
             i++;
+          else if (*c == '\\' && !escaped)
+            escaped = TRUE;
+          else
+            escaped = FALSE;
         }
       component_start = c;
     }
 
   /* find end of component */
+  escaped = FALSE;
   if (*component_start == '\0')
     component_end = component_start;
   else
     {
-      for (c = component_start; *c != '\0' && *c != ':'; c++)
-        ;
+      for (c = component_start; *c != '\0'; c++)
+        {
+          if (*c == ':' && !escaped)
+            break;
+          if (*c == '\\' && !escaped)
+            escaped = TRUE;
+          else
+            escaped = FALSE;
+        }
     }
 
   component_end = c;
